summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/gwaccount.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:03 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:03 -0600
commit9c9412b30c54468adc9e506cc76c5d113fbf5056 (patch)
tree68a0c0d5bc770fc58596b8c5624cdf33d8625027 /kopete/protocols/groupwise/gwaccount.h
parent2e53bd0b77676f879fad7baeecea5879bf496a7d (diff)
downloadtdenetwork-9c9412b30c54468adc9e506cc76c5d113fbf5056.tar.gz
tdenetwork-9c9412b30c54468adc9e506cc76c5d113fbf5056.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kopete/protocols/groupwise/gwaccount.h')
-rw-r--r--kopete/protocols/groupwise/gwaccount.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kopete/protocols/groupwise/gwaccount.h b/kopete/protocols/groupwise/gwaccount.h
index df74cf66..abce33be 100644
--- a/kopete/protocols/groupwise/gwaccount.h
+++ b/kopete/protocols/groupwise/gwaccount.h
@@ -29,7 +29,7 @@
#include <managedconnectionaccount.h>
-class KActionMenu;
+class TDEActionMenu;
namespace Kopete {
class Contact;
@@ -65,7 +65,7 @@ public:
/**
* Construct the context menu used for the status bar icon
*/
- virtual KActionMenu* actionMenu();
+ virtual TDEActionMenu* actionMenu();
// DEBUG ONLY
void dumpManagers();
@@ -322,10 +322,10 @@ protected:
void cleanup();
private:
// action menu and its actions
- KActionMenu * m_actionMenu;
- KAction * m_actionAutoReply;
- KAction * m_actionManagePrivacy;
- KAction * m_actionJoinChatRoom;
+ TDEActionMenu * m_actionMenu;
+ TDEAction * m_actionAutoReply;
+ TDEAction * m_actionManagePrivacy;
+ TDEAction * m_actionJoinChatRoom;
// Network code
KNetworkConnector * m_connector;
TQCA::TLS * m_TQCATLS;
@@ -344,7 +344,7 @@ private:
* @internal
* An action that selects an OnlineStatus and provides a status message, but not using Kopete::Away, because the status message relates only to this status.
*/
/*class OnlineStatusMessageAction : public KAction
{
Q_OBJECT
@@ -344,7 +344,7 @@ private:
* An action that selects an OnlineStatus and provides a status message, but not using Kopete::Away, because the status message relates only to this status.
*/
-/*class OnlineStatusMessageAction : public KAction
+/*class OnlineStatusMessageAction : public TDEAction
{
Q_OBJECT